@@ -46,7 +46,7 @@ static void sig_display_status(DBusGProxy *proxy, const char *status, gpointer u
 	 * in the two ButtonPress events being received before the display_status==on
 	 * event.  Check here if that's the case.
 	 */
-	if (app->display_on && app->press_count > 1 && app->last_press - time(NULL) <= 1)
+	if (app->display_on && app->press_count > 1 && time(NULL) - app->last_press <= 1)
 		speak_time(app);
 }
 
